@@ -7,7 +7,7 @@ import urllib.request
 import warnings
 from collections.abc import MutableMapping
 from http.cookiejar import Cookie, CookieJar
-from urllib.parse import parse_qsl, urlencode
+from urllib.parse import parse_qsl, quote, unquote, urlencode
 
 import chardet
 import rfc3986
@@ -24,6 +24,7 @@ from ._decoders import (
     TextDecoder,
 )
 from ._exceptions import (
+    HTTPCORE_EXC_MAP,
     CookieConflict,
     HTTPStatusError,
     InvalidURL,
@@ -32,6 +33,7 @@ from ._exceptions import (
     ResponseClosed,
     ResponseNotRead,
     StreamConsumed,
+    map_exceptions,
 )
 from ._status_codes import codes
 from ._types import (
@@ -100,12 +102,12 @@ class URL:
     @property
     def username(self) -> str:
         userinfo = self._uri_reference.userinfo or ""
-        return userinfo.partition(":")[0]
+        return unquote(userinfo.partition(":")[0])
 
     @property
     def password(self) -> str:
         userinfo = self._uri_reference.userinfo or ""
-        return userinfo.partition(":")[2]
+        return unquote(userinfo.partition(":")[2])
 
     @property
     def host(self) -> str:
@@ -175,8 +177,8 @@ class URL:
         ):
             host = kwargs.pop("host", self.host)
             port = kwargs.pop("port", self.port)
-            username = kwargs.pop("username", self.username)
-            password = kwargs.pop("password", self.password)
+            username = quote(kwargs.pop("username", self.username) or "")
+            password = quote(kwargs.pop("password", self.password) or "")
 
             authority = host
             if port is not None:
@@ -193,7 +195,7 @@ class URL:
 
     def join(self, url: URLTypes) -> "URL":
         """
-        Return an absolute URL, using given this URL as the base.
+        Return an absolute URL, using this URL as the base.
         """
         if self.is_relative_url:
             return URL(url)
@@ -409,9 +411,8 @@ class Headers(typing.MutableMapping[str, str]):
     def raw(self) -> typing.List[typing.Tuple[bytes, bytes]]:
         """
         Returns a list of the raw header items, as byte pairs.
-        May be mutated in-place.
         """
-        return self._list
+        return list(self._list)
 
     def keys(self) -> typing.KeysView[str]:
         return {key.decode(self.encoding): None for key in self._dict.keys()}.keys()
@@ -613,6 +614,9 @@ class Request:
 
     def prepare(self) -> None:
         for key, value in self.stream.get_headers().items():
+            # Ignore Transfer-Encoding if the Content-Length has been set explicitly.
+            if key.lower() == "transfer-encoding" and "content-length" in self.headers:
+                continue
             self.headers.setdefault(key, value)
 
         auto_headers: typing.List[typing.Tuple[bytes, bytes]] = []
@@ -642,8 +646,7 @@ class Request:
         if not has_connection:
             auto_headers.append((b"connection", b"keep-alive"))
 
-        for item in reversed(auto_headers):
-            self.headers.raw.insert(0, item)
+        self.headers = Headers(auto_headers + self.headers.raw)
 
     @property
     def content(self) -> bytes:
@@ -928,8 +931,9 @@ class Response:
             raise ResponseClosed()
 
         self.is_stream_consumed = True
-        for part in self._raw_stream:
-            yield part
+        with map_exceptions(HTTPCORE_EXC_MAP, request=self.request):
+            for part in self._raw_stream:
+                yield part
         self.close()
 
     def next(self) -> "Response":
@@ -953,8 +957,7 @@ class Response:
         if not self.is_closed:
             self.is_closed = True
             self._elapsed = self.request.timer.elapsed
-            if hasattr(self, "_raw_stream"):
-                self._raw_stream.close()
+            self._raw_stream.close()
 
     async def aread(self) -> bytes:
         """
@@ -1005,8 +1008,9 @@ class Response:
             raise ResponseClosed()
 
         self.is_stream_consumed = True
-        async for part in self._raw_stream:
-            yield part
+        with map_exceptions(HTTPCORE_EXC_MAP, request=self.request):
+            async for part in self._raw_stream:
+                yield part
         await self.aclose()
 
     async def anext(self) -> "Response":
@@ -1029,8 +1033,7 @@ class Response:
         if not self.is_closed:
             self.is_closed = True
             self._elapsed = self.request.timer.elapsed
-            if hasattr(self, "_raw_stream"):
-                await self._raw_stream.aclose()
+            await self._raw_stream.aclose()
 
 
 class Cookies(MutableMapping):
@@ -1044,6 +1047,10 @@ class Cookies(MutableMapping):
             if isinstance(cookies, dict):
                 for key, value in cookies.items():
                     self.set(key, value)
+        elif isinstance(cookies, list):
+            self.jar = CookieJar()
+            for key, value in cookies:
+                self.set(key, value)
         elif isinstance(cookies, Cookies):
             self.jar = CookieJar()
             for cookie in cookies.jar:
